@@ -188,8 +188,6 @@ class VolMesh(Datastructure):
 
     """
 
-    __module__ = 'compas.datastructures'
-
     def __init__(self):
         super(VolMesh, self).__init__()
         self._max_int_vkey = -1
@@ -2805,11 +2803,14 @@ class VolMesh(Datastructure):
 
 if __name__ == '__main__':
 
-    import compas
+    # import compas
 
-    volmesh = VolMesh.from_obj(compas.get('boxes.obj'))
+    # volmesh = VolMesh.from_obj(compas.get('boxes.obj'))
 
-    volmesh.summary()
+    # volmesh.summary()
 
-    for key, attr in volmesh.vertices(True):
-        print(key, attr)
+    # for key, attr in volmesh.vertices(True):
+    #     print(key, attr)
+
+    import doctest
+    doctest.testmod(globs=globals())
